<?php
require 'vendor/autoload.php';

$appPath = dirname(__FILE__) ;

$app = new \Slim\Slim();
$app->storage = new \Upload\Storage\FileSystem($appPath . '/uploads');

$app->get('/profile/:userId', function ($userId) {
	include_once 'profile_pic_form.php';
});

$app->post('/profile/:userId', function ($userId) use($app) {
	$app->response->headers->set('Content-Type', 'application/json');
	$file = new \Upload\File('profile_pic', $app->storage);
	$newFilename = uniqid();
	$file->setName($newFilename);

	// Validate file
	// MimeType List => http://www.webmaster-toolkit.com/mime-types.shtml
	$file->addValidations([
		new \Upload\Validation\Mimetype(['image/png', 'image/jpeg']),
		new \Upload\Validation\Size('5M'),
	]);
	$response = ['message' => null, 'errors' => null];
	try {
		$response['message'] = [
			'name' => $file->getNameWithExtension(),
			'mime' => $file->getMimetype(),
			'size' => $file->getSize(),
			'md5'  => $file->getMd5(),
			'dimensions' => $file->getDimensions()
		];
		$file->upload();
		$app->response->setStatus(201);
	} catch (\Exception $e) {
		$response['errors'] = $file->getErrors();
		$response['message'] = null;
		$app->response->setStatus(200);
	}
	echo json_encode($response);
});

$app->get('/file-upload', function () {
	include_once 'file_share_form.php';
});

$app->post('/file-upload', function () use($app) {
	$app->response->headers->set('Content-Type', 'application/json');
	$response = ['message' => [], 'errors' => null];
	foreach ($_FILES as $key => $data) {
		$file = new \Upload\File($key, $app->storage);
		$file->setName(uniqid());
		// Validate file
		// MimeType List => http://www.webmaster-toolkit.com/mime-types.shtml
		$file->addValidations([
			new \Upload\Validation\Mimetype(['image/png', 'image/jpeg', 'application/pdf']),
			new \Upload\Validation\Size('5M'),
		]);
		try {
			array_push($response['message'], [
				'name' => $file->getNameWithExtension(),
				'mime' => $file->getMimetype(),
				'size' => $file->getSize(),
				'md5'  => $file->getMd5(),
				'dimensions' => $file->getDimensions()
			]);
			$file->upload();
			$app->response->setStatus(201);
		} catch (\Exception $e) {
			$response['errors'] = $file->getErrors();
			$app->response->setStatus(200);
			break;
		}
	}
	echo json_encode($response);
});

$app->run();
